using BinaryProvider # requires BinaryProvider 0.3.0 or later

# Parse some basic command-line arguments
const verbose = "--verbose" in ARGS
const prefix = Prefix(get([a for a in ARGS if a != "--verbose"], 1, joinpath(@__DIR__, "usr")))
products = [
    LibraryProduct(prefix, ["libsymspg"], :libsymspg),
]

# Download binaries from hosted location
bin_prefix = "https://github.com/unkcpz/SpglibBuilder/releases/download/v1.12.2b"

# Listing of files generated by BinaryBuilder:
download_info = Dict(
    Linux(:i686, libc=:glibc) => ("$bin_prefix/SpglibBuilder.v1.12.2.i686-linux-gnu.tar.gz", "5b08ba2f36f9b69b15731ef06319916ce4847d4a73de14213146be8633cd4ce4"),
    MacOS(:x86_64) => ("$bin_prefix/SpglibBuilder.v1.12.2.x86_64-apple-darwin14.tar.gz", "fbeb59dd8f0a6f4e7b7be01dfe4bdefa7e6bf1c129361206eab5c50a56c166a5"),
    Linux(:x86_64, libc=:glibc) => ("$bin_prefix/SpglibBuilder.v1.12.2.x86_64-linux-gnu.tar.gz", "2ed0453cd784c4246f205ee7856384e0d22ed659d4dc618ffa0780e53e4df7ce"),
    FreeBSD(:x86_64) => ("$bin_prefix/SpglibBuilder.v1.12.2.x86_64-unknown-freebsd11.1.tar.gz", "ad497ff2a2388907f34d7c9b79a9b1c5894d093030e2296e9c0bb508011505c5"),
)

# Install unsatisfied or updated dependencies:
unsatisfied = any(!satisfied(p; verbose=verbose) for p in products)
dl_info = choose_download(download_info, platform_key_abi())
if dl_info === nothing && unsatisfied
    # If we don't have a compatible .tar.gz to download, complain.
    # Alternatively, you could attempt to install from a separate provider,
    # build from source or something even more ambitious here.
    error("Your platform (\"$(Sys.MACHINE)\", parsed as \"$(triplet(platform_key_abi()))\") is not supported by this package!")
end

# If we have a download, and we are unsatisfied (or the version we're
# trying to install is not itself installed) then load it up!
if unsatisfied || !isinstalled(dl_info...; prefix=prefix)
    # Download and install binaries
    install(dl_info...; prefix=prefix, force=true, verbose=verbose)
end

# Write out a deps.jl file that will contain mappings for our products
write_deps_file(joinpath(@__DIR__, "deps.jl"), products, verbose=verbose)
